autowisp.light_curves.reconstructive_correction_transit module — AutoWISP documentation

# autowisp.light_curves.reconstructive_correction_transit module

## Class Inheritance Diagram

Definet class performing reconstructive detrending on LCs with transits.

class autowisp.light_curves.reconstructive_correction_transit.ReconstructiveCorrectionTransit(transit_model, correction, fit_amplitude=True, transit_parameters=None)

  Bases: `object`

  Class for corrections that protect known or suspected transit signals.

  transit_model

    See same name argument to __init__()

  fit_amplitude

    See same name argument to __init__()

  transit_parameters

    The positional and keyword arguments to pass to the transit model’s evaluate() method.

    Type:

      2-tuple

  __call__(lc_fname, *transit_parameters_pos, save=True, **transit_parameters_kw)

    Perform reconstructive EPD on a light curve, given transit parameters.

    Parameters:

      - lc_fname (str) – The filename of the lightcurve to fit.

      - save (bool) – See same name orgument to EPDCorrection.__call__().

      - transit_parameters_pos – Positional arguments to be passed to the transit model’s evaluate() method.

      - transit_parameters_kw – Keyword arguments to be passed to the transit model’s evaluate() method.

    Returns:

      See EPDCorrection.__call__()

  __init__(transit_model, correction, fit_amplitude=True, transit_parameters=None)

    Configure the fitting.

    Parameters:

      - transit_model – If not None, this should be one of the models implemented in pytransit.

      - correction (Correction) – An instance of one of the correction classes.

      - fit_amplitude (bool) – Should the amplitude of the model be fit along with the EPD correction coefficients? If not, the amplitude of the signal is assumed known.

      - transit_parameters (2-tiple) – Positional and keyword arguments to pass to the transit model. Overwritten by __call__. The first entry should be iterable and specifies positional arguments, the second entry is dict and specifies keyword arguments.

    Returns:

      None

  get_fit_data(light_curve, dset_key, **substitutions)

    To be used as the get_fit_data argument to parent’s __call__.